==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/security/kotlin/inputs/InformationProtectionAwsOfferingInformationProtectionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.security.kotlin.inputs

import com.pulumi.azurenative.security.inputs.InformationProtectionAwsOfferingInformationProtectionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The native cloud connection configuration
 * @property cloudRoleArn The cloud role ARN in AWS for this feature
 */
public data class InformationProtectionAwsOfferingInformationProtectionArgs(
    public val cloudRoleArn: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.security.inputs.InformationProtectionAwsOfferingInformationProtectionArgs> {
    override fun toJava():
        com.pulumi.azurenative.security.inputs.InformationProtectionAwsOfferingInformationProtectionArgs =
        com.pulumi.azurenative.security.inputs.InformationProtectionAwsOfferingInformationProtectionArgs.builder()
            .cloudRoleArn(cloudRoleArn?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InformationProtectionAwsOfferingInformationProtectionArgs].
 */
@PulumiTagMarker
public class InformationProtectionAwsOfferingInformationProtectionArgsBuilder internal constructor() {
    private var cloudRoleArn: Output<String>? = null

    /**
     * @param value The cloud role ARN in AWS for this feature
     */
    @JvmName("gndggjklixbgwijk")
    public suspend fun cloudRoleArn(`value`: Output<String>) {
        this.cloudRoleArn = value
    }

    /**
     * @param value The cloud role ARN in AWS for this feature
     */
    @JvmName("brdxyocnefopvnkx")
    public suspend fun cloudRoleArn(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.cloudRoleArn = mapped
    }

    internal fun build(): InformationProtectionAwsOfferingInformationProtectionArgs =
        InformationProtectionAwsOfferingInformationProtectionArgs(
            cloudRoleArn = cloudRoleArn,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/security/kotlin/inputs/InformationProtectionAwsOfferingInformationProtectionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.security.kotlin.inputs

import com.pulumi.azurenative.security.inputs.InformationProtectionAwsOfferingInformationProtectionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The native cloud connection configuration
 * @property cloudRoleArn The cloud role ARN in AWS for this feature
 */
public data class InformationProtectionAwsOfferingInformationProtectionArgs(
    public val cloudRoleArn: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.security.inputs.InformationProtectionAwsOfferingInformationProtectionArgs> {
    override fun toJava():
        com.pulumi.azurenative.security.inputs.InformationProtectionAwsOfferingInformationProtectionArgs =
        com.pulumi.azurenative.security.inputs.InformationProtectionAwsOfferingInformationProtectionArgs.builder()
            .cloudRoleArn(cloudRoleArn?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InformationProtectionAwsOfferingInformationProtectionArgs].
 */
@PulumiTagMarker
public class InformationProtectionAwsOfferingInformationProtectionArgsBuilder internal constructor() {
    private var cloudRoleArn: Output<String>? = null

    /**
     * @param value The cloud role ARN in AWS for this feature
     */
    @JvmName("unyfiqtfoijepfiq")
    public suspend fun cloudRoleArn(`value`: Output<String>) {
        this.cloudRoleArn = value
    }

    /**
     * @param value The cloud role ARN in AWS for this feature
     */
    @JvmName("swypghcukfjblvpe")
    public suspend fun cloudRoleArn(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.cloudRoleArn = mapped
    }

    internal fun build(): InformationProtectionAwsOfferingInformationProtectionArgs =
        InformationProtectionAwsOfferingInformationProtectionArgs(
            cloudRoleArn = cloudRoleArn,
        )
}
